% /**************************************************************************************************************************
% 
% ---------------------------------------------------------------------------------------------------------------------------
% 
% Purpose:   Find estiamted ice induced resistance for given speed and ice thickness
% 
% Theory:   
% 
% Called from: main.m
% Subroutines: lindqvist.m  riska.m
% Comments
% 
% 
% Variables:
% Name           I/O       Description
% -------------------------------------------------------------------------------------------------------------------------
% H               I	Ice thickness [m]
% v               I	vessel speed [m/s]
% lindqv	  O	Estimate of resistance [kN]
% res_riska	  O	Estimate of resistance [kN]
% phi              	Ship bow angle[deg]
% alpha            	Water line entrance angle[deg]
% T                	Draught[m]
% B                	Breath[m]
% Lpp              	Length between perpendiculars[m]
% Lpar             	Length of bow section[m]
% Lbow             	Length of parallell sides section[m]
% 
% my                    Friction coefficient between ice and hull  [-]
% sigma            	Ice bending strength [Pa]
% drho             	difference between salt water density and ice density [kg/m^3]
% 
% ---------------------------------------------------------------------------------------------------------------------------
% Programmed by: Torstein Skr
% Last changed/ version:050211/1.0
% **************************************************************************************************************************/




%Returns Ice resistance based on Riska and Lindqvist formulations
function [lindqv res_riska keinon]=AnalytRes(H,v)
%% input data 
%(relevant for KV Svalbard)
Lpp=89; %[m]
Lbow=27.2;%[m]
Lpar=36.3;%[m]
B=19.1;%[m]
T=6.5;%[m]
alpha=59;%[deg]
phi=33;%[deg]


%ice constants
my=.15; %[-] Friction coeff between ice and hull
sigma=650e3;%[Pa] Ice strength in bending
drho=125; %[kg/m^3] Difference between ice and salt water density


%% run analysis
lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
keinon=keinonen(sigma,phi,T,B,Lpp,H,v);
