% function [fitresult, gof] = createSurfaceFits(Speed, IceThickness, RiskaRatio)
%CREATESURFACEFITS(SPEED,ICETHICKNESS,RISKARATIO)
%  Fit surfaces to data.
%
%  Data for 'Riska 2nd order robust' fit:
%      X Input : Speed
%      Y Input : IceThickness
%      Z Output: RiskaRatio
%  Data for 'Riska 3nd order robust' fit:
%      X Input : Speed
%      Y Input : IceThickness
%      Z Output: RiskaRatio
%  Output:
%      fitresult : a cell-array of sfit objects representing the fits.
%      gof : structure array with goodness-of fit info.
%
%  See also FIT, SFIT.

%  Auto-generated by MATLAB on 28-Apr-2011 12:46:23

%% Initialization.

% Initialize arrays to store fits and goodness-of-fit.
fitresult = cell( 2, 1 );
gof = struct( 'sse', cell( 2, 1 ), ...
    'rsquare', [], 'dfe', [], 'adjrsquare', [], 'rmse', [] );

%% Fit: 'Riska 2nd order robust'.
[xInput, yInput, zOutput] = prepareSurfaceData( Speed, IceThickness, RiskaRatio );

% Set up fittype and options.
ft = fittype( 'poly22' );
opts = fitoptions( ft );
opts.Lower = [-Inf -Inf -Inf -Inf -Inf -Inf];
opts.Robust = 'Bisquare';
opts.Upper = [Inf Inf Inf Inf Inf Inf];

% Fit model to data.
[fitresult{1}, gof(1)] = fit( [xInput, yInput], zOutput, ft, opts );

% Plot fit with data.
figure( 'Name', 'Riska 2nd order robust' );
h = plot( fitresult{1}, [xInput, yInput], zOutput );
legend( h, 'Riska 2nd order robust', 'RiskaRatio vs. Speed, IceThickness', 'Location', 'NorthEast' );
% Label axes
xlabel( 'Speed' );
ylabel( 'IceThickness' );
zlabel( 'RiskaRatio' );
grid on
view( -302.5, 20 );

%% Fit: 'Riska 3nd order robust'.
[xInput, yInput, zOutput] = prepareSurfaceData( Speed, IceThickness, RiskaRatio );

% Set up fittype and options.
ft = fittype( 'poly22' );
opts = fitoptions( ft );
opts.Lower = [-Inf -Inf -Inf -Inf -Inf -Inf];
opts.Robust = 'Bisquare';
opts.Upper = [Inf Inf Inf Inf Inf Inf];

% Fit model to data.
[fitresult{2}, gof(2)] = fit( [xInput, yInput], zOutput, ft, opts );

% Create a figure for the plots.
figure( 'Name', 'Riska 3nd order robust' );

% Plot fit with data.
subplot( 2, 1, 1 );
h = plot( fitresult{2}, [xInput, yInput], zOutput );
legend( h, 'Riska 3nd order robust', 'RiskaRatio vs. Speed, IceThickness', 'Location', 'NorthEast' );
% Label axes
xlabel( 'Speed' );
ylabel( 'IceThickness' );
zlabel( 'RiskaRatio' );
zlim([-1 5])
grid on
view( 44.5, 0 );

% Plot residuals.
subplot( 2, 1, 2 );
h = plot( fitresult{2}, [xInput, yInput], zOutput, 'Style', 'Residual' );
legend( h, 'Riska 3nd order robust - residuals', 'Location', 'NorthEast' );
% Label axes
xlabel( 'Speed' );
ylabel( 'IceThickness' );
zlabel( 'RiskaRatio' );
grid on
view( 3.5, 14 );


