%selects data based on statistics (selects data with standard deviation below given value (in relation to mean))
%timestamp for such data is saved to file and returned, may be used for data selection later
function [SelStat noice timestamp]=DataSelectStatistic (data,time,SD,control)

%% Mean/Standard deviation threshold values
% SD=.1; %only use data if standard deviation is less than given value in relation to mean
IceThreshold=0.05;% Ice thickness less than this value is taken as "No Ice". 
MaxIce=3;% Ice thickness larger than this value is considdered not relevant
SpeedThreshold=0.5;%[knots] Data points with speed less than given value will not be taken into account
[N M]=size(data);
SelStat=zeros(N,M);
noice=zeros(N,M);
CV=zeros(N,4);
timestamp=zeros(N,2);
i=1; j=1; k=0;
for n=1:N
    % find coeff of variation for sel. parameters (IceTh, speed, Course, pwr1, pwr2)
    cv=[data(n,4)/data(n,3) data(n,6)/data(n,5) data(n,8)/data(n,7) (data(n,10)/abs(data(n,9))+data(n,12)/abs(data(n,11)))/2];%IceTh, speed Course pwr1 pwr2
    % control aginst threshold values

    test=cv<=SD;% create logical values for the comparison between coeff. of variation and threshold values
    
    if data(n,5)>SpeedThreshold%only save data if vessel speed larger than threshold        
        if min(test)==true
            if data(n,3)>=IceThreshold %check for ice
                if data(n,3)<MaxIce% only save if ice thickness is in relevant band
                    SelStat(i,:)=data(n,:);
                    CV(i,:)=cv;
                    timestamp(i,:)=[data(n,1)-data(n,2)/2 data(n,1)+data(n,2)/2];
                    i=i+1;
                end
            else
                noice(j,:)=data(n,:);
                j=j+1;
            end
        end
    else
        k=k+1;
    end
end
% keyboard
noice(j-1:N,:)=[];
SelStat(i-1:N,:)=[];
timestamp(i-1:N,:)=[];
CV(i-1:N,:)=[];

% filename=['timestamp',num2str(time),'sek_SD',num2str(SD*100),'%.mat'];
% save(filename, 'timestamp');

%% Plot selected variables as function of time, in order to controll data
%% selection
if control==0 % suppression of control plots
    return
end
%% ice data
a=figure('Name','Data selected for ice conditions','NumberTitle','off'); 
hold on
plot(SelStat(:,1)-SelStat(1,1),SelStat(:,3),'g','MarkerSize',4);%mean ice thickness
plot(SelStat(:,1)-SelStat(1,1),SelStat(:,3)+2*SelStat(:,4),'r')%mean+2*SD
plot(SelStat(:,1)-SelStat(1,1),SelStat(:,3)-2*SelStat(:,4),'r')%mean-2*SD
% annotation(a,'textbox',[0.2 0.8 .2 .1],...
%             'String',{['Data plotted is mean data over ',num2str(time),' sec period']},...
%             'BackgroundColor',[1 1 1],'FitBoxToText','on');
plot(SelStat(:,1)-SelStat(1,1),SelStat(:,5),'b','MarkerSize',4)% Speed
legend('Mean ice thickness','Ice thickness +2 standard deviations','Ice thickness -2 standard deviations','Vessel Speed');%,'Location',[.225 .6 .2 .1])
xlabel(['Days since ',datestr(SelStat(1,1))])
ylabel({'Ice thickness [m]','Speed [knots]'})

%% no ice data

b=figure('Name','Data selected for no ice conditions','NumberTitle','off'); 
hold on
% plot(noice(:,1)-noice(1,1),noice(:,3),'rx');
annotation(b,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Data plotted is mean data over ',num2str(time),' sec period']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
plot(noice(:,1)-noice(1,1),noice(:,5),'bx')
legend('Vessel Speed')%,'Location',[.225 .6 .2 .1])
xlabel(['Days since ',datestr(noice(1,1))])
ylabel({'Ice thickness [m]','Speed [m/s]'})

c=figure('Name','Coefficient of variation for selected data points','NumberTitle','off','OuterPosition',[50 50 800 600]*.8);
hold on
y=size(CV,1);
h(1)=plot(CV(:,1),'rx','MarkerSize',4);h(5)=plot([0 y],[SD(1) SD(1)],'r');
h(2)=plot(CV(:,2),'bo','MarkerSize',4);h(6)=plot([0 y],[SD(2) SD(2)],'b');
h(3)=plot(CV(:,3),'g*','MarkerSize',4);h(7)=plot([0 y],[SD(3) SD(3)],'g');
h(4)=plot(CV(:,4),'m.');h(8)=plot([0 y],[SD(4) SD(4)],'m');
axis([0 i 0 max(SD)*1.03])
xlabel('Data point no')
ylabel('Coefficient of variation')

% First column
% Axes handle 1 (this is the visible axes)
ah1 = gca;
% Legend at axes 1
leg1=legend(ah1,h(1:4),'Ice Thickness','Vessel speed','Vessel Heading', 'Engine power','Location','SouthWestOutside');
set(leg1,'Position',[0.12 0.08 0.2 0.2])
% Second column
% Axes handle 2 (unvisible, only for place the second legend)
ah2=axes('position',get(gca,'position'), 'visible','off');
% Legend at axes 2
leg2=legend(ah2,h(5:8),'Ice Thickness Threshold', 'Vessel speed Threshold',  'Vessel Heading Threshold','Engine power Threshold') ;
axis([0 i 0 max(SD)*1.03])
% legend({,'Location','SouthOutside')
xlabel('Data point no')
ylabel('Coefficient of variation (\sigma/ \mu)')
filename=['Plots\CV\CV=',num2str(SD(1)),' ',num2str(SD(2)),' '...
    ,num2str(SD(3)),' ',num2str(SD(4)),' ','Time=',num2str(time),'s.emf'];
saveas(c,filename)


