% Analyses the ratio between calculated resistance and analytical estimates
function [label RegOut] = StatCalc (compare,label,RegParam,varargin)
%% Parse input arguments 
p=inputParser;

p.addRequired('compare',@isnumeric)
p.addRequired('label',@isstruct)
p.addRequired('RegParam',@isstruct)
p.addParamValue('NewPath','Plots\',@ischar)
p.parse(compare,label,RegParam,varargin{:})

root=p.Results.NewPath; %ability to modify the root folder for plots




global Torstein
%% create labels for later use
ratio=[compare(:,2) compare(:,3) compare(:,4)./compare(:,5) compare(:,4)./(compare(:,6)) compare(:,4)./(compare(:,7)) compare(:,1)];
label.ratio={label.compare{2}; label.compare{3}; [label.compare{4}(1:3),'/',label.compare{5}(1:6)];[label.compare{4}(1:3),'/',label.compare{6}(1:5)];[label.compare{4}(1:3),'/',label.compare{7}(1:5)];label.compare{1}};

%remove NaNs to prevent error
ratio(any(isnan(ratio),2),:) = [];
%load position vectors and line plot variables
[pos lst]=plotvar;
%% Plot based on time
if RegParam.timeplot==true    
    [ratio,RegParam, NewPath]=timeplot(ratio,label,RegParam);
    root=[root,NewPath];% modify root folder if date selection has been activated
end


%% Scatterplot both ratios against both parameters, before sorting
if RegParam.fullScatter==true
    fullScatter(ratio,label,pos,RegParam,root,'FitLine','poly1');      
    
end
%%

%% Fit surface to ratios
if RegParam.surffit==true
    [surface.Rfitresult, surface.Rgof] = createSurfaceFitRobust(ratio(:,1), ratio(:,2),ratio(:,4),'Riska');
    fprintf('\n-----------------------------------------------\nRiska robust surface fit:\n'); surface.Rfitresult
    fprintf('Goodness of fit paramters:\n'); disp(surface.Rgof)
    [surface.Lfitresult, surface.Lgof] = createSurfaceFitRobust(ratio(:,1), ratio(:,2),ratio(:,3),'Lindqvist');
    fprintf('-----------------------------------------------\nLindqvist robust surface fit:\n'); surface.Lfitresult
    fprintf('Goodness of fit paramters:\n'); disp(surface.Lgof)
    [surface.Kfitresult, surface.Kgof] = createSurfaceFitRobust(ratio(:,1), ratio(:,2),ratio(:,5),'Keinonen');
    fprintf('-----------------------------------------------\nKeinonen robust surface fit:\n'); surface.Kfitresult
    fprintf('Goodness of fit paramters:\n'); disp(surface.Kgof)
    RegOut.surf=surface;
end



%% Divide measurements in subgroups

%create variables
S=RegParam.bins(1);T=RegParam.bins(2);%Number of bins in speed and thickness domain

SpeedThres=0:4/S:4;
ThickThres=0:3/T:3;
sort.ratios=cell(S,T);%sorted values
sort.normal=cell(S,T);%normal distr. data, with same structure as in sort.ratios
sort.logn.Rdist=cell(S,T);
sort.logn.Ldist=cell(S,T);%Lognormal distr data for riska and lindqv ratios, incl confidence interval    
sort.logn.Kdist=cell(S,T);
label.sort=cell(S,T);
sort.logn.Rresidual=cell(S,T);
sort.logn.Lresidual=cell(S,T);                                                       
sort.logn.Kresidual=cell(S,T);
if isfield(RegParam,'distr')
    for i=1:size(RegParam.distr,2)
        sort.(RegParam.distr{i}).Rresidual=cell(S,T);
        sort.(RegParam.distr{i}).Lresidual=cell(S,T);
        sort.(RegParam.distr{i}).Kresidual=cell(S,T);
        sort.(RegParam.distr{i}).Rdist=cell(S,T);
        sort.(RegParam.distr{i}).Ldist=cell(S,T);
        sort.(RegParam.distr{i}).Kdist=cell(S,T);
    end
end
counter=ones(S,T);
% Sorting algorithm
for i=1:size(ratio,1)
    for j=1:S
        if ratio(i,1)>=SpeedThres(j) && ratio(i,1)<SpeedThres(j+1)%If correct speed bin
            for k=1:T
                if ratio(i,2)>=ThickThres(k) && ratio(i,2)<ThickThres(k+1)%If correct thickness bin
                    sort.ratios{j,k}(counter(j,k),:)=ratio(i,:);
                    counter(j,k)=counter(j,k)+1;
                end
            end
        end
    end
end

% Create labels
for s=1:S
    for t=1:T
        label.sort{s,t}=['V \in[',num2str(SpeedThres(s),'%4.2f'),',',num2str(SpeedThres(s+1),'%4.2f'),']  h \in[',num2str(ThickThres(t),'%4.2f'),',',num2str(ThickThres(t+1),'%4.2f'),']'];
        
    end
end

%% Calculate stat. values and test distibutions for subgroups
alpha=.05;
warning('off','stats:cdf:ChangedParameters');warning('off','stats:mle:ChangedParameters');warning('off','stats:icdf:ChangedParameters');% is turned on again at end of file
for s=1:S
    for t=1:T
        if size(sort.ratios{s,t},1)>RegParam.MinObs % don't calculate stat. values if to few observations
            % Normal distribution data (mean and standard deviation)
            sort.normal{s,t}(1:2,:)=[mean(sort.ratios{s,t},1);std(sort.ratios{s,t},0,1)];
            % Log-Normal distribution data
            [parmhat_r parmci_r]=lognfit(sort.ratios{s,t}(:,4),alpha);
            [parmhat_l parmci_l]=lognfit(sort.ratios{s,t}(:,3),alpha);
            [parmhat_k parmci_k]=lognfit(sort.ratios{s,t}(:,5),alpha);
            
            %% chi-square test of lognormal distribution, incl error handling
            %disable warning, and reset warning variable
            warning('off','stats:chi2gof:LowCounts')
            lastwarn('','')
            %test of lognormal dist on Riska data
            nbins=min(ceil(size(sort.ratios{s,t},1)/6),15);% mimimum number of expected observations per bin is 5, max no of bins is 15
            binedge=icdf('Lognormal',0:(1/nbins):1,parmhat_r(1),parmhat_r(2));% define bins with equal probability
            [h_r p_r str_r]=chi2gof(sort.ratios{s,t}(:,4),'cdf',{@logncdf,parmhat_r(1),parmhat_r(2)},'nparams',2,'edges',binedge);
            [WarningString WarningID]=lastwarn;
            chi2errorR=~isempty(WarningID);
            if chi2errorR==true
                disp(' ')
                disp(['Warning from chi2gof on Riska data in cell {',num2str(s),',',num2str(t),'} testing LogNormal:'])
                disp(WarningString)
            end
            lastwarn('','')
            %test of lognormal distr on Lindqvist data
            nbins=min(ceil(size(sort.ratios{s,t},1)/6),15);% mimimum number of expected observations per bin is 5, max no of bins is 15
            binedge=icdf('Lognormal',0:(1/nbins):1,parmhat_l(1),parmhat_l(2));% define bins with equal probability
            [h_l p_l str_l]=chi2gof(sort.ratios{s,t}(:,3),'cdf',{@logncdf,parmhat_l(1),parmhat_l(2)},'nparams',2,'edges',binedge);
            % catch warning
            [WarningString WarningID]=lastwarn;
            chi2errorL=~isempty(WarningID);
            if chi2errorL==true
                disp(' ')
                disp(['Warning from chi2gof on Lindqvist data in cell {',num2str(s),',',num2str(t),'} testing LogNormal:'])
                disp(WarningString)
            end
             %test of lognormal distr on Keinonen data
            nbins=min(ceil(size(sort.ratios{s,t},1)/6),15);% mimimum number of expected observations per bin is 5, max no of bins is 15
            binedge=icdf('Lognormal',0:(1/nbins):1,parmhat_k(1),parmhat_k(2));% define bins with equal probability
            [h_k p_k str_k]=chi2gof(sort.ratios{s,t}(:,5),'cdf',{@logncdf,parmhat_k(1),parmhat_k(2)},'nparams',2,'edges',binedge);
            % catch warning
            [WarningString WarningID]=lastwarn;
            chi2errorK=~isempty(WarningID);
            if chi2errorK==true
                disp(' ')
                disp(['Warning from chi2gof on Keinonen data in cell {',num2str(s),',',num2str(t),'} testing LogNormal:'])
                disp(WarningString)
            end
            
            
            sort.logn.Ldist{s,t}=[h_r p_r;parmhat_l ;parmci_l;chi2errorL 0];        %Her var det feil chi2errorL og chi2errorR var byttet om
            sort.logn.Rdist{s,t}=[h_l p_l;parmhat_r ;parmci_r;chi2errorR 0];
            sort.logn.Kdist{s,t}=[h_k p_k;parmhat_k ;parmci_k;chi2errorK 0];
            
            %% test other distributions
            if isfield(RegParam,'distr') %if other distributions
                Rdata=sort.ratios{s,t}(:,4);
                Ldata=sort.ratios{s,t}(:,3);
                Kdata=sort.ratios{s,t}(:,5);
                for i=1:size(RegParam.distr)%for all other distr
                    %Lindqvist
                    [phat pci] = mle(Ldata,'dist',RegParam.distr{i});% calc weibull parameters
                    fun = @(data,mu,sig)cdf(RegParam.distr{i},data,mu,sig);% create function handle for cumulative distribution function
                    
                    nbins=min(ceil(size(sort.ratios{s,t},1)/6),15);% mimimum number of expected observations per bin is 5, max no of bins is 15
                    binedge=icdf(RegParam.distr{i},0:(1/nbins):1,phat(1),phat(2));% define bins with equal probability
                    lastwarn('','')
                    [h_test p_test]=chi2gof(Ldata,'cdf',{fun,phat(1),phat(2)},'nparams',2,'edges',binedge);
                    
                    %handle warnings
                    [WarningString WarningID]=lastwarn;
                    chi2error=0;
                    if strncmp(WarningID,'stats:chi2gof',13)% if last warning is from chi2 test
                        chi2error=1;
                        disp(' ')
                        disp(['Warning from chi2gof on Lindqvist data in cell {',num2str(s),',',num2str(t),'} testing ',RegParam.distr{i},':'])
                        disp(WarningString)
                    end
                    sort.(RegParam.distr{i}).Ldist{s,t}=[h_test p_test;phat;pci;chi2error 0];
                    
                    %Riska
                    [phat pci] = mle(Rdata,'dist',RegParam.distr{i});% calc weibull parameters
                    fun = @(data,mu,sig)cdf(RegParam.distr{i},data,mu,sig);% create function handle for cumulative distribution function
                    
                    nbins=min(ceil(size(sort.ratios{s,t},1)/6),15);% mimimum number of expected observations per bin is 5, max no of bins is 15
                    binedge=icdf(RegParam.distr{i},0:(1/nbins):1,phat(1),phat(2));% define bins with equal probability
                    lastwarn('','')
                    [h_test p_test]=chi2gof(Rdata,'cdf',{fun,phat(1),phat(2)},'nparams',2,'edges',binedge);
                    
                    %handle warnings
                    [WarningString WarningID]=lastwarn;
                    chi2error=0;
                    if strncmp(WarningID,'stats:chi2gof',13)% if last warning is from chi2 test
                        chi2error=1;
                        disp(' ')
                        disp(['Warning from chi2gof on Riska data in cell {',num2str(s),',',num2str(t),'} testing ',RegParam.distr{i},':'])
                        disp(WarningString)
                    end
                    sort.(RegParam.distr{i}).Rdist{s,t}=[h_test p_test;phat;pci;chi2error 0];
                    
                    %Keinonen
                    [phat pci] = mle(Kdata,'dist',RegParam.distr{i});% calc weibull parameters
                    fun = @(data,mu,sig)cdf(RegParam.distr{i},data,mu,sig);% create function handle for cumulative distribution function
                    
                    nbins=min(ceil(size(sort.ratios{s,t},1)/6),15);% mimimum number of expected observations per bin is 5, max no of bins is 15
                    binedge=icdf(RegParam.distr{i},0:(1/nbins):1,phat(1),phat(2));% define bins with equal probability
                    lastwarn('','')
                    [h_test p_test]=chi2gof(Kdata,'cdf',{fun,phat(1),phat(2)},'nparams',2,'edges',binedge);
                    
                    %handle warnings
                    [WarningString WarningID]=lastwarn;
                    chi2error=0;
                    if strncmp(WarningID,'stats:chi2gof',13)% if last warning is from chi2 test
                        chi2error=1;
                        disp(' ')
                        disp(['Warning from chi2gof on Keinonen data in cell {',num2str(s),',',num2str(t),'} testing ',RegParam.distr{i},':'])
                        disp(WarningString)
                    end
                    sort.(RegParam.distr{i}).Kdist{s,t}=[h_test p_test;phat;pci;chi2error 0];
                    
                end
            end
            
            
            
        end
    end
end
warning('on','stats:chi2gof:LowCounts')
label.distribution={'Chi-square test result (0=accept lognormal)','Propability of getting data set from given distr';'mu','sigma'...
    ;'mu lower confidence bound','sigma lower conf. bound';'mu upper conf. interval','sigma upper conf. interval';'chi2gof bin error','0'};
%% Plot sorted data in subplots with scatter
if RegParam.dividedScatter==true
    for x=1:2
        for y=3:5
            a=figure('Name',[label.ratio{y},' ratio plotted against ',label.ratio{x}],...
                'NumberTitle','off','OuterPosition',pos{5});
            i=1;
            for s=1:S
                for t=1:T
                    h(i)=subplot(S,T,i);
                    if isempty(sort.ratios{s,t})==false % Only plot if data
                        scatter(sort.ratios{s,t}(:,x),sort.ratios{s,t}(:,y),'.')
                        if size(sort.ratios{s,t},1)>=2,axis ([min(sort.ratios{s,t}(:,x)) max(sort.ratios{s,t}(:,x)) 0 2])
                        else axis ([sort.ratios{s,t}(1,x)*.8 sort.ratios{s,t}(1,x)*1.2 0 2]),end
                        NumTicks = 3;
                        L = get(gca,'XLim');
                        ticks=linspace(L(1),L(2),NumTicks);
                        set(gca,'XTick',ticks)
                        set(gca,'xticklabel',num2str(ticks.','%5.1f'));
                        set(h(i),'YTick',1:2);
                    else
                        text(.1,.5,'{\bf No data}')
                    end
                    i=i+1;
                end
            end
            %print main title
            mtit([label.ratio{y},' ratio plotted against ',label.ratio{x}],'fontsize',16,'color',[0 0 0],'xoff',0,'yoff',.025)
            % Fix labels on main x and y axis
            k=1;
            for j=1:S:i-1
                set(get(h(j),'YLabel'),'String',['V\in[',num2str(SpeedThres(k),'%11.2g'),' , ',num2str(SpeedThres(k+1),'%11.2g'),']'])
                k=k+1;
            end
            k=1;
            for j=S*T-T+1:S*T
                set(get(h(j),'XLabel'),'String',['h\in[',num2str(ThickThres(k),'%11.2g'),' , ',num2str(ThickThres(k+1),'%11.2g'),']'])
                k=k+1;
            end
            if RegParam.save==true
                UsePath=[root,'Ratios\'];
                if isempty(dir(UsePath));
                    mkdir(UsePath)
                end
                filename=[label.ratio{y}(1:3),label.ratio{y}(5:9),' vs ',label.ratio{x}(1:6),'-splitted.emf'];
                saveas(a,[UsePath,filename])
                close
            end
        end
    end
end
%% Plot sorted data in a more structured way, incl moving average
if RegParam.intScatter==true
    for y=3:5;% for riska, lindqvist and keinonen ratio
        % Plot against speed
        a=figure('Name',[label.ratio{y},' ratio plotted against ',label.ratio{1}],...
            'NumberTitle','off','OuterPosition',pos{5});
        h=cell(1,T);
        for t =1:T
            h{t}=subplot(T,1,T-t+1);
            p=get(h{t},'pos');
            p(4)=p(4)+0.02*5/T; %decrease space between scatterplots
            set(h{t},'pos',p)
            xvar=0;yvar=0;
            for s=1:S% collect plotting terms over relevant cells
                if ~isempty(sort.ratios{s,t})
                    xvar=vertcat(xvar,sort.ratios{s,t}(:,1));  yvar=vertcat(yvar,sort.ratios{s,t}(:,y));
                end
            end
            % data smoothing
            yy=smooth(xvar,yvar,31);
            smpl=[xvar yy];
            smpl=sortrows(smpl,1);
            hold on
            scatter(xvar,yvar,'.')
            plot(smpl(:,1),smpl(:,2),'-r')
            axis([0 4 0 2])
            ylabel({'H [m]\in';['[',num2str(ThickThres(t),'%11.2g'),',',num2str(ThickThres(t+1),'%11.2g'),'] '];'';'Ratio'})
            set(gca,'xticklabel',[])
            grid on
        end
        %activate xticks on lower subplot
        set(h{1},'xtickMode', 'auto','xticklabelMode','auto')
        set(get(h{1},'XLabel'),'String',label.ratio{1})
        %save file
        if RegParam.save==true
            UsePath=[root,'Ratios\'];
            if isempty(dir(UsePath));
                mkdir(UsePath)
            end
            filename=[label.ratio{y}(1:3),label.ratio{y}(5:9),' vs ',label.ratio{1}(1:6),'.emf'];    %HER BLIR DET FEEEEEEIL M
            saveas(a,[UsePath,filename])
            close
        end
        % Plot against thickness
        a=figure('Name',[label.ratio{y},' ratio plotted against ',label.ratio{2}],...
            'NumberTitle','off','OuterPosition',pos{5});
        h=cell(1,S);
        for s =1:S
            h{s}=subplot(S,1,S-s+1);
            p=get(h{s},'pos');
            p(4)=p(4)+0.02*5/S; %decrease space between scatterplots
            set(h{s},'pos',p)
            xvar=0;yvar=0;
            for t=1:T% collect plotting terms over relevant cells
                if ~isempty(sort.ratios{s,t})
                    xvar=vertcat(xvar,sort.ratios{s,t}(:,2));  yvar=vertcat(yvar,sort.ratios{s,t}(:,y));
                end
            end
            yy=smooth(xvar,yvar,31);
            smpl=[xvar yy];
            smpl=sortrows(smpl,1);
            hold on
            scatter(xvar,yvar,'.')
            plot(smpl(:,1),smpl(:,2),'-r')
            axis([0 3 0 2])
            ylabel({'V [m/s]\in';['[',num2str(SpeedThres(s),'%11.2g'),',',num2str(SpeedThres(s+1),'%11.2g'),'] '];'';'Ratio'})
            set(gca,'xticklabel',[])
            grid on
        end
        %acticate x-tics on lower subplot
        set(h{1},'xtickMode', 'auto','xticklabelMode','auto')
        set(get(h{1},'XLabel'),'String',label.ratio{2})
        %save image
        if RegParam.save==true
            UsePath=[root,'Ratios\'];
            if isempty(dir(UsePath));
                mkdir(UsePath)
            end
            filename=[label.ratio{y}(1:3),label.ratio{y}(5:9),' vs ',label.ratio{2}(1:12),'.emf'];
            saveas(a,[UsePath,filename])
            close
        end
    end
end
%% Plot Log-Normal distribution, incl confidence interval

if RegParam.lognormal(1)==true
    
    if RegParam.lognormal(3)==true
        subpl=[2,2];
    else
        subpl=[1,2];
    end
    for s=1:S
        for t=1:T
            %% Riska
            if size(sort.ratios{s,t},1)>RegParam.MinObs %only plot if data set is not empty
                h=figure('Name',[label.ratio{4},' ratio tested as a Log-Normal distribution in interval: ',label.sort{s,t},'    s=',num2str(s),' t=',num2str(t)],...
                    'NumberTitle','off','OuterPosition',pos{5});
                subplot(subpl(1),subpl(2),1)
                % normalized histogram and lognormal curves
                histnorm(sort.ratios{s,t}(:,4))
                hold on
                % plot Log-NormalProbability density function, incl conf. intervals
                x=0:.01:max(sort.ratios{s,t}(:,4)+.5);
                y=lognpdf(x,sort.logn.Rdist{s,t}(2,1),sort.logn.Rdist{s,t}(2,2));%(x,mu,sigma)
                ymax=lognpdf(x,sort.logn.Rdist{s,t}(4,1),sort.logn.Rdist{s,t}(4,2));
                ymin=lognpdf(x,sort.logn.Rdist{s,t}(3,1),sort.logn.Rdist{s,t}(3,2));
                plot(x,y,'r',x,ymin,'m',x,ymax,'g','LineWidth',1.5)
                %                 title(label.sort{s,t})
                legend('Normalized histogram','Log-Normal PDF',['Lower ',num2str((1-alpha)*100),'% Confidence interval'],...
                    ['Upper ',num2str((1-alpha)*100),'% Confidence interval'],'Location','SouthOutside')
                xlabel([label.ratio{4},' ratio'])
                hold off
                
                hPrbPl=subplot(subpl(1),subpl(2),2);% probability plots
                data = sort.ratios{s,t}(:,4);
                probplot('lognormal',data);% lognormal probability plot
                sort.logn.Rresidual{s,t}=Torstein;
                legnd={'Log Normal','Data'};
                if isfield(RegParam,'distr')
                    for i=1:size(RegParam.distr,2)
                        p = mle(data,'dist',RegParam.distr{i});% calc distribution parameters
                        fun = @(data,mu,sig)cdf(RegParam.distr{i},data,mu,sig);% create function handle for cumulative distribution function
                        ax = probplot(hPrbPl,fun,p);% Plot line of new cdf in prob. plot
                        set(ax,'color',lst.col{i+3},'linestyle','-')
                        sort.(RegParam.distr{i}).Rresidual{s,t}=Torstein;
                    end
                    legnd={'Log Normal','Data',RegParam.distr{1:i}};
                end
                xlabel(' ')
                title(' ')
                legend(legnd,'Location','SO')
                mtit(h,[label.ratio{4},' ratio tested as a Log-Normal distribution in interval: ',label.sort{s,t}],'fontsize',14,'color',[0 0 0],'xoff',0,'yoff',.025)
                %Check chi squared test result
                if sort.logn.Rdist{s,t}(1,1)==0 && sort.logn.Rdist{s,t}(5,1)==0 && isnan(sort.logn.Rdist{s,t}(1,2))==false 
                    txt={'\chi^2 test performed without error:'; 'Log-Normality accepted';[' P=',num2str(sort.logn.Rdist{s,t}(1,2))]};
                elseif sort.logn.Rdist{s,t}(1,1)==1&&sort.logn.Rdist{s,t}(5,1)==0 && isnan(sort.logn.Rdist{s,t}(1,2))==false
                    txt={'\chi^2 test performed without error:'; 'Log-Normality not accepted';[' P=',num2str(sort.logn.Rdist{s,t}(1,2))]};
                elseif sort.logn.Rdist{s,t}(5,1)==0 && isnan(sort.logn.Rdist{s,t}(1,2))
                    txt={'error in \chi^2 test','Not enough degrees of freedom'};
                else
                    txt={'error in \chi^2 test.','See command window for furter info'};
                end
                annotation(h,'textbox',[0.58 0.81 .2 .1],...
                    'String',txt,...
                    'BackgroundColor',[1 1 1],'FitBoxToText','on');
                if RegParam.lognormal(3)==true % Scatterplott
                    subplot(subpl(1),subpl(2),3)
                    scatter(sort.ratios{s,t}(:,1),sort.ratios{s,t}(:,4),'.')
                    title([label.ratio{4},' ratio plotted against ',label.ratio{1}])
                    xlabel(label.ratio{1})
                    ylabel('ratio')
                    % Scatterplot
                    subplot(subpl(1),subpl(2),4)
                    scatter(sort.ratios{s,t}(:,2),sort.ratios{s,t}(:,4),'.')
                    title([label.ratio{4},' ratio plotted against ',label.ratio{2}])
                    xlabel(label.ratio{2})
                    ylabel('ratio')
                end
                if RegParam.save==true
                    UsePath=[root,'Lognormal distribution\'];
                    filename=[label.ratio{4}(1:3),label.ratio{4}(5:9),...
                        ' V =[',num2str(SpeedThres(s),'%11.2f'),',',num2str(SpeedThres(s+1),'%11.2f'),'] h=[',num2str(ThickThres(t),'%11.2f'),...
                        ',',num2str(ThickThres(t+1),'%11.2f'),'].emf'];
                    A4(h)
                    if isempty(dir(UsePath)),mkdir(UsePath),end
                    print(h,'-dmeta','-r300',[UsePath,filename])
                    if isfield(RegParam,'distr')
                        for i=1:size(RegParam.distr,2)
                            UsePath=[root,RegParam.distr{i},' distribution\'];
                            if isempty(dir(UsePath)),mkdir(UsePath),end
                            print(h,'-dmeta','-r300',[UsePath,filename])
                        end
                    end
                    delete(h)
                end
                % needs modified probplot. to work:
                % line 80: insert global torstein;
                % line 178: insert torstein.linefun=linefun;
                % line 278: insert global torstein; torstein.ydata=q; torstein.xdata=x;
                
                %% Create new prob plot for secondary distributions
                if isfield(RegParam,'distr')
                    for i=1:size(RegParam.distr,2)
                        if probplotSupport(RegParam.distr{i})==true
                            h=figure;
                            probplot(RegParam.distr{i},data);
                            title([label.ratio{4},' ratio tested as a ',RegParam.distr{i},' distribution in interval: ',label.sort{s,t}])
                            set(gca,'XtickLabel',get(gca,'Xtick'))
                            xlabel([label.ratio{4}, ' Ratio'])
                            if RegParam.save==true
                                UsePath=[root,RegParam.distr{i},' distribution\'];
                                print('-dmeta','-r300',[UsePath,'A-',filename])                                
                                delete(h)
                            end
                        end
                    end
                end
                
                
                %% Lindqvist
                h=figure('Name',[label.ratio{3},' ratio tested as a Log-Normal distribution in interval: ',label.sort{s,t},'    s=',num2str(s),' t=',num2str(t)],...
                    'NumberTitle','off','OuterPosition',pos{5});
                subplot(subpl(1),subpl(2),1)
                % normalized histogram and lognormal curves
                histnorm(sort.ratios{s,t}(:,3))
                hold on
                % plot Log-NormalProbability density function, incl conf. intervals
                x=0:.01:max(sort.ratios{s,t}(:,3)+.5);
                y=lognpdf(x,sort.logn.Ldist{s,t}(2,1),sort.logn.Ldist{s,t}(2,2));%(x,mu,sigma)
                ymax=lognpdf(x,sort.logn.Ldist{s,t}(4,1),sort.logn.Ldist{s,t}(4,2));
                ymin=lognpdf(x,sort.logn.Ldist{s,t}(3,1),sort.logn.Ldist{s,t}(3,2));
                plot(x,y,'r',x,ymin,'m',x,ymax,'g','LineWidth',1.5)
                %                 title(label.sort{s,t})
                legend('Normalized histogram','Log-Normal PDF',['Lower ',num2str((1-alpha)*100),'% Confidence interval'],...
                    ['Upper ',num2str((1-alpha)*100),'% Confidence interval'],'Location','SO')
                xlabel([label.ratio{3},' ratio'])
                hold off
                
                hPrbPl=subplot(subpl(1),subpl(2),2);
                data = sort.ratios{s,t}(:,3);
                probplot('lognormal',data);% lognormal probability plot
                sort.logn.Lresidual{s,t}=Torstein;
                legnd={'Log Normal','Data'};
                if isfield(RegParam,'distr')
                    for i=1:size(RegParam.distr,2)
                        % Plot line in existing prob. plot
                        p = mle(data,'dist',RegParam.distr{i});% calc distribution parameters
                        fun = @(data,mu,sig)cdf(RegParam.distr{i},data,mu,sig);% create function handle for cumulative distribution function
                        ax = probplot(hPrbPl,fun,p);% Plot line of new cdf in prob. plot
                        set(ax,'color',lst.col{i+3},'linestyle','-')
                        sort.(RegParam.distr{i}).Lresidual{s,t}=Torstein;                        
                    end
                    legnd={'Log Normal','Data',RegParam.distr{1:i}};
                end
                title(' ')
                xlabel(' ')
                legend(legnd,'Location','SO')
                mtit(h,[label.ratio{3},' ratio tested as a Log-Normal distribution in interval: ',label.sort{s,t}],'fontsize',14,'color',[0 0 0],'xoff',0,'yoff',.025)
                %Check chi squared test result
                if sort.logn.Ldist{s,t}(1,1)==0 && sort.logn.Ldist{s,t}(5,1)==0 && isnan(sort.logn.Ldist{s,t}(1,2))==false 
                    txt={'\chi^2 test performed without error:'; 'Log-Normality accepted';[' P=',num2str(sort.logn.Ldist{s,t}(1,2))]};
                elseif sort.logn.Ldist{s,t}(1,1)==1&&sort.logn.Ldist{s,t}(5,1)==0 && isnan(sort.logn.Ldist{s,t}(1,2))==false
                    txt={'\chi^2 test performed without error:'; 'Log-Normality not accepted';[' P=',num2str(sort.logn.Ldist{s,t}(1,2))]};
                elseif sort.logn.Ldist{s,t}(5,1)==0 && isnan(sort.logn.Ldist{s,t}(1,2))
                    txt={'error in \chi^2 test','Not enough degrees of freedom'};
                else
                    txt={'error in \chi^2 test.','See command window for furter info'};
                end
                annotation(h,'textbox',[0.58 0.81 .2 .1],...
                    'String',txt,...
                    'BackgroundColor',[1 1 1],'FitBoxToText','on');
                
                if RegParam.lognormal(3)==true% Scatterplott
                    subplot(subpl(1),subpl(2),3)
                    scatter(sort.ratios{s,t}(:,1),sort.ratios{s,t}(:,3),'.')
                    title([label.ratio{3},' ratio plotted against ',label.ratio{1}])
                    xlabel(label.ratio{1})
                    ylabel('ratio')
                    % Scatterplot
                    subplot(subpl(1),subpl(2),4)
                    scatter(sort.ratios{s,t}(:,2),sort.ratios{s,t}(:,3),'.')
                    title([label.ratio{3},' ratio plotted against ',label.ratio{2}])
                    xlabel(label.ratio{2})
                    ylabel('ratio')
                end
                if RegParam.save==true
                    UsePath=[root,'Lognormal distribution\'];
                    if isempty(dir(UsePath));
                        mkdir(UsePath)
                    end
                    filename=[label.ratio{3}(1:3),label.ratio{3}(5:9),...
                        ' V =[',num2str(SpeedThres(s),'%5.2f'),',',num2str(SpeedThres(s+1),'%5.2f'),'] h=[',num2str(ThickThres(t),'%5.2f'),...
                        ',',num2str(ThickThres(t+1),'%5.2f'),'].emf'];
                    A4(h)
                    print(h,'-dmeta','-r300',[UsePath,filename])
                    if isfield(RegParam,'distr')
                        for i=1:size(RegParam.distr,2)
                            UsePath=[root,RegParam.distr{i},' distribution\'];
                            print(h,'-dmeta','-r300',[UsePath,filename])
                        end
                    end
                    delete(h)%to prevent memory errors
                end
                
                % Needs modified probplot. to work:
                % line 80: insert global Torstein;
                % line 178: insert Torstein.linefun=linefun;
                % line 278: insert global Torstein; Torstein.ydata=q; Torstein.xdata=x;
                
                %% Create new prob plot for secondary distributions
                if isfield(RegParam,'distr')
                    for i=1:size(RegParam.distr,2)
                        if probplotSupport(RegParam.distr{i})==true
                            h=figure;
                            probplot(RegParam.distr{i},data);
                            title([label.ratio{3},' ratio tested as a ',RegParam.distr{i},' distribution in interval: ',label.sort{s,t}])
                            set(gca,'XtickLabel',get(gca,'Xtick'))
                            xlabel([label.ratio{3}, ' Ratio'])
                            if RegParam.save==true
                                UsePath=[root,RegParam.distr{i},' distribution\'];
                                print('-dmeta','-r300',[UsePath,'A-',filename])
                                delete(h)
                            end
                        end
                    end
                end
                
                %% Keinonen
                h=figure('Name',[label.ratio{5},' ratio tested as a Log-Normal distribution in interval: ',label.sort{s,t},'    s=',num2str(s),' t=',num2str(t)],...
                    'NumberTitle','off','OuterPosition',pos{5});
                subplot(subpl(1),subpl(2),1)
                % normalized histogram and lognormal curves
                histnorm(sort.ratios{s,t}(:,5))
                hold on
                % plot Log-NormalProbability density function, incl conf. intervals
                x=0:.01:max(sort.ratios{s,t}(:,5)+.5);
                y=lognpdf(x,sort.logn.Kdist{s,t}(2,1),sort.logn.Kdist{s,t}(2,2));%(x,mu,sigma)
                ymax=lognpdf(x,sort.logn.Kdist{s,t}(4,1),sort.logn.Kdist{s,t}(4,2));
                ymin=lognpdf(x,sort.logn.Kdist{s,t}(3,1),sort.logn.Kdist{s,t}(3,2));
                plot(x,y,'r',x,ymin,'m',x,ymax,'g','LineWidth',1.5)
                %                 title(label.sort{s,t})
                legend('Normalized histogram','Log-Normal PDF',['Lower ',num2str((1-alpha)*100),'% Confidence interval'],...
                    ['Upper ',num2str((1-alpha)*100),'% Confidence interval'],'Location','SouthOutside')
                xlabel([label.ratio{5},' ratio'])
                hold off
                
                hPrbPl=subplot(subpl(1),subpl(2),2);% probability plots
                data = sort.ratios{s,t}(:,5);
                probplot('lognormal',data);% lognormal probability plot
                sort.logn.Kresidual{s,t}=Torstein;
                legnd={'Log Normal','Data'};
                if isfield(RegParam,'distr')
                    for i=1:size(RegParam.distr,2)
                        p = mle(data,'dist',RegParam.distr{i});% calc distribution parameters
                        fun = @(data,mu,sig)cdf(RegParam.distr{i},data,mu,sig);% create function handle for cumulative distribution function
                        ax = probplot(hPrbPl,fun,p);% Plot line of new cdf in prob. plot
                        set(ax,'color',lst.col{i+3},'linestyle','-')
                        sort.(RegParam.distr{i}).Kresidual{s,t}=Torstein;
                    end
                    legnd={'Log Normal','Data',RegParam.distr{1:i}};
                end
                xlabel(' ')
                title(' ')
                legend(legnd,'Location','SO')
                mtit(h,[label.ratio{5},' ratio tested as a Log-Normal distribution in interval: ',label.sort{s,t}],'fontsize',14,'color',[0 0 0],'xoff',0,'yoff',.025)
                %Check chi squared test result
                if sort.logn.Kdist{s,t}(1,1)==0 && sort.logn.Kdist{s,t}(5,1)==0 && isnan(sort.logn.Kdist{s,t}(1,2))==false 
                    txt={'\chi^2 test performed without error:'; 'Log-Normality accepted';[' P=',num2str(sort.logn.Kdist{s,t}(1,2))]};
                elseif sort.logn.Kdist{s,t}(1,1)==1&&sort.logn.Kdist{s,t}(5,1)==0 && isnan(sort.logn.Kdist{s,t}(1,2))==false
                    txt={'\chi^2 test performed without error:'; 'Log-Normality not accepted';[' P=',num2str(sort.logn.Kdist{s,t}(1,2))]};
                elseif sort.logn.Kdist{s,t}(5,1)==0 && isnan(sort.logn.Kdist{s,t}(1,2))
                    txt={'error in \chi^2 test','Not enough degrees of freedom'};
                else
                    txt={'error in \chi^2 test.','See command window for furter info'};
                end
                annotation(h,'textbox',[0.58 0.81 .2 .1],...
                    'String',txt,...
                    'BackgroundColor',[1 1 1],'FitBoxToText','on');
                if RegParam.lognormal(3)==true % Scatterplott
                    subplot(subpl(1),subpl(2),3)
                    scatter(sort.ratios{s,t}(:,1),sort.ratios{s,t}(:,5),'.')
                    title([label.ratio{5},' ratio plotted against ',label.ratio{1}])
                    xlabel(label.ratio{1})
                    ylabel('ratio')
                    % Scatterplot
                    subplot(subpl(1),subpl(2),4)
                    scatter(sort.ratios{s,t}(:,2),sort.ratios{s,t}(:,5),'.')
                    title([label.ratio{5},' ratio plotted against ',label.ratio{2}])
                    xlabel(label.ratio{2})
                    ylabel('ratio')
                end
                if RegParam.save==true
                    UsePath=[root,'Lognormal distribution\'];
                    filename=[label.ratio{5}(1:3),label.ratio{5}(5:9),...
                        ' V =[',num2str(SpeedThres(s),'%11.2f'),',',num2str(SpeedThres(s+1),'%11.2f'),'] h=[',num2str(ThickThres(t),'%11.2f'),...
                        ',',num2str(ThickThres(t+1),'%11.2f'),'].emf'];
                    A4(h)
                    if isempty(dir(UsePath)),mkdir(UsePath),end
                    print(h,'-dmeta','-r300',[UsePath,filename])
                    if isfield(RegParam,'distr')
                        for i=1:size(RegParam.distr,2)
                            UsePath=[root,RegParam.distr{i},' distribution\'];
                            if isempty(dir(UsePath)),mkdir(UsePath),end
                            print(h,'-dmeta','-r300',[UsePath,filename])
                        end
                    end
                    delete(h)
                end
                % needs modified probplot. to work:
                % line 80: insert global torstein;
                % line 178: insert torstein.linefun=linefun;
                % line 278: insert global torstein; torstein.ydata=q; torstein.xdata=x;
                
                %% Create new prob plot for secondary distributions
                if isfield(RegParam,'distr')
                    for i=1:size(RegParam.distr,2)
                        if probplotSupport(RegParam.distr{i})==true
                            h=figure;
                            probplot(RegParam.distr{i},data);
                            title([label.ratio{5},' ratio tested as a ',RegParam.distr{i},' distribution in interval: ',label.sort{s,t}])
                            set(gca,'XtickLabel',get(gca,'Xtick'))
                            xlabel([label.ratio{5}, ' Ratio'])
                            if RegParam.save==true
                                UsePath=[root,RegParam.distr{i},' distribution\'];
                                print('-dmeta','-r300',[UsePath,'A-',filename])                                
                                delete(h)
                            end
                        end
                    end
                end
            end
            %             break
            
        end
        %         break
        end
    end
    
    %% Plot residuals from main distribution
    if RegParam.lognormal(2)==true
        RL=[' ';' ';'L';'R';'K'];                                       %M B
        SSR=cell(5,1);                                       %M B
        for y=3:5 %All ratios
            if y==3
                residual=sort.logn.Lresidual;
            elseif y==4;
                residual=sort.logn.Rresidual;
            elseif y==5;
                residual=sort.logn.Kresidual;
            end
            name=['Residuals from statistical fitting of ',label.ratio{y},' ratio to Log-Normal Distribution'];
            hFig=figure('Name',name,'NumberTitle','off','OuterPosition',pos{5});
            i=1;clear legnd;
            for s=1:S
                for t=1:T
                    if isempty(residual{s,t})==false %only attempt to plot if data
                        [hLine(i) SSR{y}(s,t)]=probresiduals(residual{s,t},'new');%line handle and average squared error       %M B
                        set(hLine(i),'Color',lst.col{s},'LineStyle',lst.style{t})%,'Marker',lst.marker{t}
                        legnd{i}=[label.sort{s,t},' n=',num2str(size(sort.ratios{s,t},1))];
                        i=i+1;
                    end
                end
            end
            legnd{i}='Perfect fit';
            axis tight
            xaxis=get(gca, 'XLim');
            plot(xaxis,[0 0],'Color',lst.col{s+1},'LineWidth',1)
            ylim([-1.5 1.5])
            legend(legnd,'Location','EO')
            xlabel([label.ratio{y},' Ratio'],'FontSize',14)
            ylabel('Relative distance from distribution line','FontSize',14)
            mtit(name, 'FontSize',14,'xoff',.05)
            set(gca,'XtickLabel',get(gca,'Xtick'))
            
            if RegParam.save==true
                UsePath=[root,'Statistical residuals\'];
                if isempty(dir(UsePath));
                    mkdir(UsePath)
                end
                filename=['residuals from ',label.ratio{y}(5:length(label.ratio{y})),' fitted to Log-Normal distr'];
                A4(hFig)
                print('-dmeta','-r100',[UsePath,filename])

            end
            %% residuals for sec. prob distr
            if isfield(RegParam,'distr')
                for j=1:size(RegParam.distr,2)
                    name=['Residuals from statistical fitting of ',label.ratio{y},' ratio to ',RegParam.distr{j},'  Distribution'];
                    hFig=figure('Name',name,'NumberTitle','off','OuterPosition',pos{5});
                    residual=sort.(RegParam.distr{j}).([RL(y),'residual']);
                    i=1;
                    for s=1:S
                        for t=1:T
                            if isempty(residual{s,t})==false %only attempt to plot if data
                                [hLine SSR{y}(s,t)]=probresiduals(residual{s,t},'line');%line handle and average squared error      %M B
                                set(hLine,'Color',lst.col{s},'LineStyle',lst.style{t})%,'Marker',lst.marker{t}
                                legnd{i}=[label.sort{s,t},' n=',num2str(size(sort.ratios{s,t},1))];
                                i=i+1;
                            end
                        end
                    end
                    axis tight
                    xaxis=get(gca, 'XLim');
                    plot(xaxis,[0 0],'Color',lst.col{s+1},'LineWidth',1)
                    ylim([-1.5 1.5])
                    legend(legnd,'Location','EO')
                    xlabel([label.ratio{y},' Ratio'],'FontSize',14)
                    
                    ylabel('Relative distance from distribution line','FontSize',14)
                    mtit(name, 'FontSize',14,'xoff',.05)
                    set(gca,'XtickLabel',get(gca,'Xtick'))
                end
                if RegParam.save==true
                    UsePath=[root,'Statistical residuals\'];
                    if isempty(dir(UsePath));
                        mkdir(UsePath)
                    end
                    filename=['residuals from ',label.ratio{y}(5:length(label.ratio{y})),' fitted to ',RegParam.distr{j},' distr'];
                    A4(hFig)
                    print('-dmeta','-r100',[UsePath,filename])
                end
            end
        end               
    end

%% generate output to screen
if RegParam.lognormal(4)==true,tablegenerator(sort,SpeedThres,ThickThres,S,T,RegParam),end
%% save output
RegOut.sort=sort;
RegOut.ratio=ratio;
RegOut.root=root;
%% reactivate warnings
warning('on','stats:cdf:ChangedParameters');warning('on','stats:mle:ChangedParameters');warning('on','stats:icdf:ChangedParameters')



%% Documentation
% Possible string values for distribution selection using "mle" and "cdf":
% 'kernel' 
% 'beta'
% 'binomial'
% 'birnbaumsaunders'
% 'exponential'
% 'extreme value' 
% 'gamma'
% 'generalized extreme value' 
% 'generalized pareto' 
% 'inversegaussian'
% 'logistic'
% 'loglogistic'
% 'lognormal'
% 'nakagami'
% 'negative binomial' 
% 'normal'
% 'poisson'
% 'rayleigh'
% 'rician'
% 'tlocationscale'
% 'weibull'

% Possible string values for distribution selection using "probplot":
% 'exponential'      Exponential probability plot (nonnegative values)
% 'extreme value'    Extreme value probability plot (all values)
% 'lognormal'        Lognormal probability plot (positive values)
% 'normal'           Normal probability plot (all values)
% 'rayleigh'         Rayleigh probability plot (positive values)
% 'weibull'          Weibull probability plot (positive values)

% comments on chi2gof
% The chi square goodness of fit divides bins between maximum and minimum 
% value in X vector. To ensure equal probability for all bins, inverse 
% cummulative probability function (icdf) is used, which solves problem with outliers 
% (which may give p=NaN, indicating to few degrees of freedom)