function createPowerFit(ratio)
%CREATEFIT Create plot of data sets and fits
%   CREATEFIT(T,L,R)
%   Creates a plot, similar to the plot in the main Curve Fitting Tool,
%   using the data that you provide as input.  You can
%   use this function with the same data you used with CFTOOL
%   or with different data.  You may want to edit the function to
%   customize the code and this help message.
%
%   Number of data sets:  2
%   Number of fits:  5
t=ratio(:,2);l=ratio(:,3);r=ratio(:,4);
% Data from data set "l vs. t":
%     X = t:
%     Y = l:
%     Unweighted

% Data from data set "r vs. t":
%     X = t:
%     Y = r:
%     Unweighted

% Auto-generated by MATLAB on 02-Jun-2011 20:24:45

% Set up figure to receive data sets and fits
f_ = clf;
figure(f_);
set(f_,'Units','Pixels','Position',[919 376 680 471]);
% Line handles and text for the legend.
legh_ = [];
legt_ = {};
% Limits of the x-axis.
xlim_ = [Inf -Inf];
% Axes for the plot.
ax_ = axes;
set(ax_,'Units','normalized','OuterPosition',[0 0 1 1]);
set(ax_,'Box','on');
axes(ax_);
hold on;

% --- Plot Lindqvist data vs ice thickness
t = t(:);
l = l(:);
h_ = line(t,l,'Parent',ax_,'Color',[0.333333 0 0.666667],...
    'LineStyle','none', 'LineWidth',1,...
    'Marker','.', 'MarkerSize',12);
xlim_(1) = min(xlim_(1),min(t));
xlim_(2) = max(xlim_(2),max(t));
legh_(end+1) = h_;
legt_{end+1} = 'l vs. t';



% Nudge axis limits beyond data limits
if all(isfinite(xlim_))
    xlim_ = xlim_ + [-1 1] * 0.01 * diff(xlim_);
    set(ax_,'XLim',xlim_)
else
    set(ax_, 'XLim',[0.23395894027673594, 3.9769464242355372]);
end

% --- Create fit "linq lower"

% Apply exclusion rule "lower boundary l copy 1"
if length(t)~=182
    error( 'GenerateMFile:IncompatibleExclusionRule',...
        'Exclusion rule ''%s'' is incompatible with ''%s''.',...
        'lower boundary l copy 1', 't' );
end
ex_ = true(length(t),1);
ex_([1 (3:6) (9:12) (14:18) (42:49) 55 62 63 65 77 (84:123) 125 128 129 131 132 134 138]) = 0;
ok_ = isfinite(t) & isfinite(l);
if ~all( ok_ )
    warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
end
st_ = [0.27299928103237431 -1.1524456916804731 0.0066802066891113749 ];
ft_ = fittype('power2');

% Fit this model using new data
if sum(~ex_(ok_))<2
    % Too many points excluded.
    error( 'GenerateMFile:NotEnoughDataAfterExclusionRule',...
        'Not enough data left to fit ''%s'' after applying exclusion rule ''%s''.',...
        'linq lower', 'lower boundary l copy 1' );
else
    cf_ = fit(t(ok_),l(ok_),ft_,'Startpoint',st_,'Exclude',ex_(ok_));
end
% Alternatively uncomment the following lines to use coefficients from the
% original fit. You can use this choice to plot the original fit against new
% data.
%    cv_ = { 0.32294134700122101, -1.054368428241192, -0.048756427954736441};
%    cf_ = cfit(ft_,cv_{:});

% Plot this fit
h_ = plot(cf_,'fit',0.95);
set(h_(1),'Color',[1 0 0],...
    'LineStyle','-', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);
% Turn off legend created by plot method.
legend off;
% Store line handle and fit name for legend.
legh_(end+1) = h_(1);
legt_{end+1} = 'linq lower';




% --- Create fit "lindq"
ok_ = isfinite(t) & isfinite(l);
if ~all( ok_ )
    warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
end
st_ = [0.39568415600935902 -0.95556570261149343 -0.026242332394590548 ];
ft_ = fittype('power2');

% Fit this model using new data
cf_ = fit(t(ok_),l(ok_),ft_,'Startpoint',st_);
% Alternatively uncomment the following lines to use coefficients from the
% original fit. You can use this choice to plot the original fit against new
% data.
%    cv_ = { 0.15416204776920167, -1.4252410300528466, 0.22708167047574976};
%    cf_ = cfit(ft_,cv_{:});

% Plot this fit
h_ = plot(cf_,'fit',0.95);
set(h_(1),'Color',[0.333333 0.333333 0.333333],...
    'LineStyle','-', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);
% Turn off legend created by plot method.
legend off;
% Store line handle and fit name for legend.
legh_(end+1) = h_(1);
legt_{end+1} = 'lindq';



%%

figure(f_);
set(f_,'Units','Pixels','Position',[919 376 680 471]);
% Line handles and text for the legend.
legh_ = [];
legt_ = {};
% Limits of the x-axis.
xlim_ = [Inf -Inf];
% Axes for the plot.
ax_ = axes;
set(ax_,'Units','normalized','OuterPosition',[0 0 1 1]);
set(ax_,'Box','on');
axes(ax_);
hold on;


% --- Plot Riska data vs ice thickness
r = r(:);
h_ = plot(t,r,'Color',[0.333333 0.666667 0],...
    'LineStyle','none', 'LineWidth',1,...
    'Marker','.', 'MarkerSize',12);
xlim_(1) = min(xlim_(1),min(t));
xlim_(2) = max(xlim_(2),max(t));
legh_(end+1) = h_;
legt_{end+1} = 'r vs. t';

% --- Create fit "riska lower"

% Apply exclusion rule "lower boundary r copy 1"
if length(t)~=182
    error( 'GenerateMFile:IncompatibleExclusionRule',...
        'Exclusion rule ''%s'' is incompatible with ''%s''.',...
        'lower boundary r copy 1', 't' );
end
ex_ = true(length(t),1);
ex_([1 (3:6) 11 (13:18) 42 43 45 (47:49) (84:87) (89:93) 95 97 99 102 (104:118) (120:123) 125 126 131 182]) = 0;
ok_ = isfinite(t) & isfinite(r);
if ~all( ok_ )
    warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
end
st_ = [0.28368517816153921 -0.61032457762571113 0.013671747642013125 ];
ft_ = fittype('power2');

% Fit this model using new data
if sum(~ex_(ok_))<2
    % Too many points excluded.
    error( 'GenerateMFile:NotEnoughDataAfterExclusionRule',...
        'Not enough data left to fit ''%s'' after applying exclusion rule ''%s''.',...
        'riska lower', 'lower boundary r copy 1' );
else
    cf_ = fit(t(ok_),r(ok_),ft_,'Startpoint',st_,'Exclude',ex_(ok_));
end
% Alternatively uncomment the following lines to use coefficients from the
% original fit. You can use this choice to plot the original fit against new
% data.
%    cv_ = { 0.57973900638221754, -0.41594290344699553, -0.30130467108570241};
%    cf_ = cfit(ft_,cv_{:});

% Plot this fit
h_ = plot(cf_,'fit',0.95);
set(h_(1),'Color',[0 0 1],...
    'LineStyle','-', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);
% Turn off legend created by plot method.
legend off;
% Store line handle and fit name for legend.
legh_(end+1) = h_(1);
legt_{end+1} = 'riska lower';



% --- Create fit "riska"
ok_ = isfinite(t) & isfinite(r);
if ~all( ok_ )
    warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
end
st_ = [0.39568415600935902 -0.95556570261149343 ];
ft_ = fittype('power1');

% Fit this model using new data
cf_ = fit(t(ok_),r(ok_),ft_,'Startpoint',st_);
% Alternatively uncomment the following lines to use coefficients from the
% original fit. You can use this choice to plot the original fit against new
% data.
%    cv_ = { 0.41680826405113153, -0.28647517175218384};
%    cf_ = cfit(ft_,cv_{:});

% Plot this fit
h_ = plot(cf_,'fit',0.95);
set(h_(1),'Color',[0.666667 0.333333 0],...
    'LineStyle','-', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);
% Turn off legend created by plot method.
legend off;
% Store line handle and fit name for legend.
legh_(end+1) = h_(1);
legt_{end+1} = 'riska';





% --- Finished fitting and plotting data. Clean up.
hold off;
% Display legend
% leginfo_ = {'Orientation', 'vertical', 'Location', 'NorthEast'};
% h_ = legend(ax_,legh_,legt_,leginfo_{:});
% set(h_,'Interpreter','none');
% % Remove labels from x- and y-axes.
% xlabel(ax_,'');
% ylabel(ax_,'');
