function [fitresult, gof] = createSurfaceFitRobust(Speed, IceThickness, Ratio,name)
%CREATESURFACEFIT2(SPEED,ICETHICKNESS,RISKARATIO)
%  Fit surface to data.
%
%  Data for 'Riska 2nd order robust' fit:
%      X Input : Speed
%      Y Input : IceThickness
%      Z Output: RiskaRatio
%  Output:
%      fitresult : an sfit object representing the fit.
%      gof : structure with goodness-of fit info.
%
%  See also FIT, SFIT.

%  Auto-generated by MATLAB on 28-Apr-2011 13:02:25
% modified by T.Skr

xInput=Speed;         %Dette maa sls p eller prepareSurf m skaffes!!!!
yInput=IceThickness;
zOutput=Ratio;

%% Fit: 'Riska 2nd order robust'.
% [xInput, yInput, zOutput] = prepareSurfaceData( Speed, IceThickness, Ratio );

% Set up fittype and options.
ft = fittype( 'poly22' );
opts = fitoptions( ft );
opts.Lower = [-Inf -Inf -Inf -Inf -Inf -Inf];
opts.Robust = 'Bisquare';
opts.Upper = [Inf Inf Inf Inf Inf Inf];

% Fit model to data.
[fitresult, gof] = fit( [xInput, yInput], zOutput, ft, opts );

% Create a figure for the plots.
f(1)=figure( 'Name', [name,'2nd order robust'] );

% Plot fit with data.

h = plot( fitresult, [xInput, yInput], zOutput ,'XLim',[1 4],'YLim',[0 3]);
% legend( h, [name,' 2nd order robust'], [name,' Ratio vs. Speed, IceThickness'], 'Location', 'NO' );
title ({['Weighted R^2 value  = ',num2str(gof.rsquare*100,'%11.2g'),'%'],['Root Mean Square Error = ',num2str(gof.rmse,'%11.2g'),'[-]']})
% Label axes
xlabel( 'Speed [m/s]' );
ylabel( 'Ice Thickness [m]' );
zlabel( [name,' Ratio'] );
grid on
zlim([-.5 5])
view( -302.5, 20 );

% Plot residuals.
f(2)=figure( 'Name', [name,'2nd order robust'] );
h = plot( fitresult, [xInput, yInput], zOutput, 'Style', 'Residual','XLim', [1 4],'YLim',[0 3]);% plot function in curve fitting toolbox, can be tweaked
% file location : C:\Program Files\MATLAB\R2010b\toolbox\curvefit\curvefit\@sfit
legend( h, [name,' 2nd order robust surface - residuals'], 'Location', 'NO' );
% Label axes
xlabel( 'Speed [m/s]' );
ylabel( 'Ice Thickness [m]' );
zlabel( [name,' Ratio Residual'] );
grid on
view( 50, 18 );
path='Plots\Surface Fits\';
if isempty(dir(path));
    mkdir(path)
end
filename=[name,'Ratio fitted to surface.emf'];
saveas(f(1),[path,filename])
filename=[name,'Ratio fitted to surface - residuals.emf'];
saveas(f(2),[path,filename])
