% Script for symbolc calculation of flexural strength of first-year ice
% ref: Timco, G.W. and W.F. Weeks, A review of the engineering properties
% of sea ice. Cold Regions Science and Technology, 2010. 60(2): p. 107-129.
% written by Torstein Skr, spring 2011

%% define symbolic variables, and equations
syms T S h sigma ny_b real

S=(4.606+91.603/h) ;%[ppt] eq (5)
ny_b=S*(49.185/abs(T)+0.532);%[ppt] eq (6)
sigma=1.76*exp(-5.88*sqrt(ny_b/1000));% [MPa] eq (11) comment: ny_b should be a fraction, not ppt

%% plot sigma as function of temp and ice floe thickness 
close all

a=figure('Name','Flexural strength of first year ice','NumberTitle','off');
ezsurf(sigma,[-22.9 -.5 0 200])
% title('Flexural strength of first-year ice as a function of ice thickness and average ice temperature')
title('')
zlabel('\sigma_b [MPa]')
xlabel('Temperature [\circC]')
ylabel('Ice Thickness [cm]')

hold on
tmp=ones(11,10)*.5;
x=-5:-2:-23;y=0:20:200;

surf(x,y,tmp,'FaceAlpha',0.8,'EdgeColor','red')
saveas(a,'Plots\FlexuralSurface.emf')
%%
b=figure('Name','Flexural strength of first year ice','NumberTitle','off');
ezcontour(sigma,[-22.9 -.5 0 200])
% title('Flexural strength of first-year ice as a function of ice thickness and average ice temperature')
title('')
zlabel('\sigma_b [MPa]')
xlabel('Temperature [\circC]')
ylabel('Ice Thickness [cm]')
colorbar
colormap(jet)

hcb = colorbar('YTickLabel',...
{'0.2 [MPa]','0.3 [MPa]','0.4 [MPa]','0.5 [MPa]','0.6 [MPa]','0.7 [MPa]','0.8 [MPa]'});
set(hcb,'YTickMode','manual')
saveas(b,'Plots\FlexuralContour.emf')
%% Print equation to screen
pretty(simplify(sigma))