% fullScatter(ratio,label,pos) plots full scatter plots of Riska, Lindqvist and Keinonen
% ratios aginst both vessel speed and ice thickness.
% 
% fullScatter(ratio,label,pos,'MovingAverage',n) plots full scatter of both
% ratios versus both predictor variables and includes a moving average
% line, which averages over n data points

% Written by Torstein Skr as part of a Masters Thesis
% Modified by Ingvill Thorsen April 2012

function []=fullScatter(ratio,label,pos,RegParam,root,varargin)
%Plots both ratios against both predictor variables, and include moving
%average if applicable

%% Parse input arguments 
p=inputParser;

p.addRequired('ratio',@isnumeric)
p.addRequired('label',@isstruct)
p.addRequired('pos',@iscell)
p.addRequired('RegParam',@isstruct)
p.addRequired('root',@ischar)
p.addParamValue('FitLine','off',@ischar)
p.addParamValue('MovingAverage',0,@isnumeric)
p.addParamValue('NewPath','Plots\',@ischar)
p.parse(ratio,label,pos,RegParam,root,varargin{:})

%%


j=1;
for x=1:2
    for y=3:5
        % data smoothing
        
        % plot
        hfig=figure('Name',[label.ratio{y},' ratio plotted against ',label.ratio{x}],...
            'NumberTitle','off','OuterPosition',[50 50 600 600]);
        hold on
        
        if p.Results.MovingAverage~=0% moving average
            yy=smooth(ratio(:,x),ratio(:,y),p.Results.MovingAverage);
            smoothplot=[ratio(:,x) yy];
            smoothplot=sortrows(smoothplot,1);
            plot(smoothplot(:,1),smoothplot(:,2),'-r')
            legend('Data','Moving average')
        end
        if strcmpi( p.Results.FitLine,'off')~=true %fitted line
            [curvefit gof output]=fit(ratio(:,x),ratio(:,y),fittype(p.Results.FitLine));
            fprintf('\n Data from fitted line to %s vs %s \n',label.ratio{y},label.ratio{x})
            disp(curvefit),disp(gof)
            [h,prob]=chi2gof(output.residuals);
            fprintf('Results from Chi-square normal distribution test: P= %6.3g\n',prob)
            subplot(2,1,2)
            
            hPlot=plot(curvefit,'residuals',ratio(:,x),ratio(:,y),.95);

            axis tight
            
            title('Residuals from fitted line')
            legend('Residuals','Zero','Location','NW')
            xlabel(label.ratio{x})
            subplot(2,1,1)            
            plot(curvefit,'fit',ratio(:,x),ratio(:,y),.95);
            axis tight
            
            legend(label.ratio{y},'Fitted line','Location','NW')
        else
            scatter(ratio(:,x),ratio(:,y),'.')
            xlim(min(get(gca,'Xlim'),[0 4]))
            ylim(min(get(gca,'Ylim'),[0 5]))
        end
        
        title([label.ratio{y},' ratio plotted against ',label.ratio{x}])
        ylabel([label.ratio{y}, ' Ratio'])
        
        xlabel(label.ratio{x})

        j=j+1;
        if RegParam.save==true
            path=[root,'Ratios\'];
            if isempty(dir(path));
                mkdir(path)
            end
            filename=[label.ratio{y}(1:3),label.ratio{y}(5:9),' vs ',label.ratio{x}(1:6),' line_',p.Results.FitLine,'.emf'];
            saveas(hfig,[path,filename])
            close
        end
    end
end

