% Main script for Project thesis
%Programmed by Torstein Skr fall 2010
clear
clc
 
%% Load or create statistical data
time=input('Select period length for statistical data calculation. If 0 is chosen, you will be promted to give existing filename for this dataset\n');
if time==0
    file=input('Filename (including single quotation marks) containing stat. data?\n');
    load(file);
else
    %load raw data
    load ('Raw.mat','*data')  %loads data files, skipping label files
    data=stat(ICEdata, NAVdata, HMADBdata,time);%create new stat file
end

%% Select measurements sequences
selectionmethod=input('\nPlease chose data selection method:\n 1=timestamp\n 2=statistical\n !! NB Statistical selection not reliable per 20.12.2010 !!\n');
switch selectionmethod
    case(1)
        sel=DataSelectTimestamp(data);%(based on timestamps)
    case(2)
        [SelStat noice timestamp]=DataSelectStatistic(data,time);%based on low standard deviation
    otherwise
        error('Incorrect data selection method. Please se code documentation')
end 

%% calculate resistance 
M=6530;%[tonne] Ship displacement 
switch selectionmethod
    case(1)%(based on timestamps)        
        Res=ResistanceCalc(sel,M,time);
    case(2)%based on low standard deviation
        ResNoIce=ResistanceCalc(noice,M,time);        
        Res=ResistanceCalc(SelStat,M,time);        
end


        

%% Compare with Riska and Lindqvist formulation
compare=zeros(size(sel,1),6);
for i=1:size(Res,1)%calculate Riska and Lindqvist resistance
    %Known data (Excel time, speed, IceTh, ResCalc)
    compare(i,1:4)=[m2xdate(Res(i,1)) Res(i,3) Res(i,2) Res(i,4)];
    % calculate Riska and Lindqvist resistance for given ice th. and speed
    [compare(i,5) compare(i,6)]=AnalytRes(compare(i,3),compare(i,2));
    %NB: open water resistance not accounted for!!!

    %Excel time Speed IceTh ResCalculated ResLindqvist ResRiska
end
fprintf('NB: Open water resistance term in Riska formulation hs to be accounted for in excel\n')
CompareLabels={'Excel Time';'speed';'IceTh';'ResCalc';'ResLindqv';'ResRiska'};% will be headers in excel

%% Write to excel file
[n ~]=size(compare);
switch selectionmethod
    case(1)%(based on timestamps)
        xlswrite('..\FromMatlabTimestamp.xlsx',compare,['Results ',num2str(time),' sek'],['A2:F',num2str(n+1)])% results
        xlswrite('..\FromMatlabTimestamp.xlsx',CompareLabels',['Results ',num2str(time),' sek'],'A1:F1')% labels
    case(2)%based on low standard deviation
        xlswrite('..\FromMatlabStat.xlsx',compare,['Results ',num2str(time),' sek'],['A2:F',num2str(n+1)])% results
        xlswrite('..\FromMatlabStat.xlsx',CompareLabels',['Results ',num2str(time),' sek'],'A1:F1')% labels
end




%% Plot
scrsz = get(0,'ScreenSize');
close all

%%
% figure('Name','Hull resistance plotted against speed with ice conditions',...
%     'OuterPosition',[1 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2],'NumberTitle','off')
% scatter(ResIce(:,3),ResIce(:,4),6,ResIce(:,2),'.')
% axis([0 4 0 8e3])
% % title('Hull resistance plotted against speed with ice conditions')
% ylabel('Resistance [kN]')
% xlabel('speed [m/s]')
% h=colorbar;
% ylabel(h,'Ice thickness [m]')
% 
%%
figure('Name','Hull resistance plotted against speed without ice',...
    'NumberTitle','off','OuterPosition',[1 scrsz(4)/20 scrsz(3)/2 scrsz(4)/2-scrsz(4)/20])
scatter(ResNoIce(:,3),ResNoIce(:,4),'o')
% title('Hull resistance plotted against speed without ice')
ylabel('Resistance [kN]')
xlabel('speed [m/s]')
axis([0 4 0 1.5e3])
% 
%%
% figure('Name','Hull resistance plotted against ice thickness',...
%     'OuterPosition',[scrsz(3)/2 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2],'NumberTitle','off')
% scatter(ResIce(:,2),ResIce(:,4),8,ResIce(:,3),'.' )
% % title('Hull resistance plotted against ice thickness')
% axis([0 2 0 7e3])
% ylabel('Resistance [kN]')
% xlabel('Ice thickness [m]')
% h=colorbar;
% ylabel(h,'Speed [m/s]')

%%
figure('Name','Hull resistance plotted against ice thickness for selected data',...
    'OuterPosition',[scrsz(3)/2 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2],'NumberTitle','off')
scatter(Res(:,2),Res(:,4),5,Res(:,3),'o' )
title('Hull resistance plotted against ice thickness')
% axis([0 3 0 3e7])
ylabel('Resistance [kN]')
xlabel('Ice thickness [m]')
h=colorbar;
ylabel(h,'Speed [m/s]')

%%
figure('Name','Hull resistance plotted against ice thickness for statisticly selected data',...
    'OuterPosition',[1 scrsz(4)/20 scrsz(3)/2 scrsz(4)/2-scrsz(4)/20],'NumberTitle','off')
scatter(ResStat(:,2),ResStat(:,4),5,ResStat(:,3),'o' )%x,y,size,colormap
title('Hull resistance plotted against ice thickness')
% axis([0 3 0 3e7])
ylabel('Resistance [kN]')
xlabel('Ice thickness [m]')
h=colorbar;
ylabel(h,'Speed [m/s]')

