% Main script for Master thesis
% Programmed by Torstein Skr spring 2011
clear;clc;close all;

 %% read input file
[time FileSelect FileResistance Mean_SD_Ratio NewOpenWater control selectmethod RegParam]=lesinput();  
%% Load or create statistical data
if time==0
    load( FileSelect )
else
    %load raw data,
    load ('Raw.mat','*data')  %loads data files, skipping label files
    [data dataLabel FileSelect]=stat(ICEdata, NAVdata, HMADBdata,time);%create new stat file  
    
end
%% Print relevant info to screen
header(FileResistance,FileSelect,selectmethod);
label.data=dataLabel; %insert labels in a struct
%% Select data sets 
switch selectmethod  
    case 0 %based on statistical analysis
    [SelStat noice timestamp]=DataSelectStatistic(data,time,Mean_SD_Ratio,control); 
    % Calculate resistance based on low resolution data
    M=6375;%[tonne] Ship displacement
    [ResStat label]=ResistanceCalc(SelStat,M,time,label);
    case 1 %based on Madsen (2010)
        timestamp=madsen();
        load ('OpenWaterResistance.mat')
    case 2 % Based on Abdillah Suyuthi
        timestamp=suyuthi();
        load ('OpenWaterResistance.mat')
end

%% Calculate open water resistance?
if NewOpenWater==true && selectmethod==0   
    %% Calculate ice and open water resistance from selected data
    M=6375;%[tonne] Ship displacement
    [Row_model]=OpenWaterResistance(noice,M,time); 
elseif NewOpenWater==false
    %% Load existing open water resistance      
    load ('OpenWaterResistance.mat')
elseif NewOpenWater==true && selectmethod~=0
    error('Open water resistance can only be calculated if data selection method is set to 0. Current value is %i',selectmethod)
else 
    error('Invalid value for variable "NewOpenWater". Accepted values are true (1) and false (0)')
end
% keyboard


%% Use timestamps to select data with higher resolution
load (FileResistance)
[SelTime]=DataSelectTimestamp (data,timestamp,control);

%% Calculate ice resistance based on data with high resolution
%M=6530;%[tonne] Ship displacement
M=6375;
[ResTime label]=ResistanceCalc(SelTime,M,time,label);

%% Calculate riska and lindqvist resistance for selected data
Res=ResTime;%chose which resistance set to be compared with analytic sol.

compare=zeros(size(Res,1),7);
for i=1:size(Res,1)%calculate Riska and Lindqvist resistance
    if sum(Res(i,2:3)<0)==0 %only compare if speed and ice thickness is positive
    %Known data (Matlab time, speed, IceTh, ResCalc)
    compare(i,1:4)=[Res(i,1) Res(i,3) Res(i,2) Res(i,4)];
    % calculate Riska, Keinonen and Lindqvist resistance for given ice th. and speed
    [compare(i,5) compare(i,6) compare(i,7)]=AnalytRes(Res(i,2),Res(i,3));
    compare(i,6)=compare(i,6)+R_ow(compare(i,2),Row_model);% account for open water resistance
    compare(i,7)=compare(i,7)+R_ow(compare(i,2),Row_model);% account for open water resistance
    %compare(i,5)=compare(i,5)+R_ow(compare(i,2),Row_model);% account for open water resistance
    end
end

label.compare={'Matlab Time';'Speed [m/s]';'Ice Thickness [m]';'Estimated Resistance';'Lindqvist Resistance';'Riska Resistance';'Keinonen Resistance'};% will be headers in excel
%% Statistical calculations
[label RegOut]=StatCalc(compare,label,RegParam);



