% /**************************************************************************************************************************
% 
% ---------------------------------------------------------------------------------------------------------------------------
% 
% Purpose:   Estimate resistance based on formulation by Riska et al 
% 
% Theory:   Lindqvist, G. A straightforward method for calculation of ice resistance 
% Kaj Riska, M.W., Kim Englund, Topi Leivisk, Performance of merchant 
% vessels in ice in the Baltic. 
% Helsinki university of technology - Ship Laboratory, 1997
% Equation numbers refer to this paper
% 
% Called from: AnalytRes.m
% Subroutines: None
% Comments
% 
% 
% Variables:
% Name           I/O       Description
% -------------------------------------------------------------------------------------------------------------------------
% phi             I	Ship bow angle[deg]
% T               I	
% B               I	Breath[m]
% Lpp             I	Length between perpendiculars[m]
% Lpar            I	Length of bow section[m]
% Lbow            I	Length of parallell sides section[m]
% H               I	Ice thickness [m]
% v               I	vessel speed [m/s]
% riska 	  O	Estimate of resistance [kN]
% 
% 
% ---------------------------------------------------------------------------------------------------------------------------
% Programmed by: Torstein Skr
% Last changed/ version:050211/1.0
% **************************************************************************************************************************/


function r=riska(phi,B,Lpar,Lpp,Lbow,T,H,v)% angles in degrees, length in SI, resistance in kN


% constants

f1=.23;
f2=4.58;
f3=1.47;
f4=.29;
g1=18.9;
g2=.67;
g3=1.55;

C1=f1/(2*T/B+1)*B*Lpar*H+(1+.021*phi)*(f2*B*H^2+f3*Lbow*H^2+f4*B*Lbow*H);
C2=(1+.063*phi)*(g1*H^1.5+g2*B*H)+g3*H*(1+1.2*T/B)*B^2/sqrt(Lpp);
r=C1+v*C2;
