%script to run sensitivity analysis for selected parameters in ice
%resistance formulations
clear all
close all
pos=plotvar;
pos{1}=pos{1}*.8;
%% Input
%(relevant for KV Svalbard)
Lpp=89; %[m]
Lbow=27.2;%[m]
Lpar=36.3;%[m]
B=19.9;%[m]
T=6.5;%[m]
t=-10; %temperatur deg
alpha=59;%[deg]waterline entrance angle
phi=33;%[deg] stem/bow angle
phi_b=30;%[deg] buttock angle
%ice constants
my=.15; %[-] Friction coeff between ice and hull
sigma=650e3;%[Pa] Ice strength in bending
drho=125; %[kg/m^3] Difference between ice and salt water density
%% speed and ice thickness
%v=3; %[m/s]
%H=.8; %[m]
fid=fopen('sens.txt','w');
%%
for v=2
    for H=1
        %% reference resistance
        L=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
        R=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
        K=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
        %% phi
        j=1;
        for r=.5:.1:1.5
            phi=r*phi;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            %keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            phi_sens(j,:)=[r lindqv/L res_riska/R];
            j=j+1;
            phi=33;
        end
        %% sigma
        j=1;        
        for r=.5:.1:1.5
            sigma=sigma*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            sigma_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            sigma=650e3;
            file{2}={sigma_sens};
        end                
        %% my
        j=1;        
        for r=.5:.1:1.5
            my=my*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            my_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            my=.15;
            file{3}={my_sens};
        end                       
        %% Alpha
        j=1;
        for r=.5:.1:1.5
            alpha=alpha*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            alpha_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            alpha=59;%[deg]
            file{4}={alpha_sens};
        end        
        %% Lbow
        j=1;
        for r=.5:.1:1.5
            Lbow=Lbow*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            Lbow_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            Lbow=27.2;%[m]
            file{5}={Lbow_sens};
        end               
        %% Lpar
        j=1;
        for r=.5:.1:1.5
            Lpar=Lpar*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            Lpar_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            Lpar=36.3;%[m]
            file{6}={Lpar_sens};
        end        
        %% Temperature
        j=1;
        for r=.2:.1:1.8
            t=t*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            t_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            t=-10;%[deg celcius]
            file{7}={t_sens};
        end 
         %% Buttock angle
        j=1;
        for r=.5:.1:1.5
            phi_b=phi_b*r;
            lindqv=lindqvist(sigma,drho,phi,alpha,T,B,Lpp,H,v,my);
            res_riska=riska(phi,B,Lpar,Lpp,Lbow,T,H,v);
            keinon=keinonen(t,sigma,phi_b,T,B,Lpp,H,v);
            phi_b_sens(j,:)=[r lindqv/L res_riska/R keinon/K];
            j=j+1;
            phi_b=30;%[deg]
            file{8}={phi_b};
        end 
%        Plot
     %   keyboard
        scrsz = get(0,'ScreenSize');
        close all        
        %phi
        a=figure('Name','Sensitivity of of bow angle phi',...
            'OuterPosition',pos{1},'NumberTitle','off');       
        plot( phi_sens(:,1),phi_sens(:,2:3))
        axis([.5 1.50 .6 1.8 ])
        title('Bow angle \phi')
        annotation(a,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: \phi = ',num2str(phi),' [deg]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter \phi change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1);
        grid on
        legend('Lindqvist','Riska','KV Svalbard')      
        saveas(a,['Sensitivity\phi_h',num2str(H*10),'v',num2str(v),'.emf'])     
       
        %% sigma
        b=figure('Name','Sensisivity of breaking strength',...
            'OuterPosition',pos{1},'NumberTitle','off');
        plot( sigma_sens(:,1),sigma_sens(:,2),sigma_sens(:,1),sigma_sens(:,4))
        axis([.5 1.50 .6 1.5])
        title('Ice bending strength \sigma _b')
        grid on
        annotation(b,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: \sigma = ',num2str(sigma*1e-3),' [MPa]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter \sigma_b change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'Red');
        legend('Lindqvist','Keinonen','KV Svalbard')
        saveas(b,['Sensitivity\sigma_h',num2str(H*10),'v',num2str(v),'.emf'])       
        %% my
        c=figure('Name','Sensitivity of of friction coeff',...
            'OuterPosition',pos{1},'NumberTitle','off');
        plot( my_sens(:,1),my_sens(:,2))
        grid on
        axis([.5 1.50 .7 1.35])
        title('Friction coefficient ( \mu ) between ice and ship hull')
        xlabel('Parameter \mu change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'Red');
        annotation(c,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: \mu = ',num2str(my),' [-]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        legend('Lindqvist','KV Svalbard')
        saveas(c,['Sensitivity\my_h',num2str(H*10),'v',num2str(v),'.emf'])
        %% alpha
        d=figure('Name','Sensitivity of of water line entrance angle alpha',...
            'OuterPosition',pos{1},'NumberTitle','off');        
        plot( alpha_sens(:,1),alpha_sens(:,2))
        axis([.5 1.50 .6 1.8 ])
        title('Water line entrance angle \alpha')
        annotation(d,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: \alpha = ',num2str(alpha),' [deg]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter \alpha change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'Red');        
        grid on
        legend('Lindqvist','KV Svalbard')
        saveas(d,['Sensitivity\alpha_h',num2str(H*10),'v',num2str(v),'.emf'])       
        %% Lbow
        e=figure('Name','Sensitivity of Bow section length',...
            'OuterPosition',pos{1},'NumberTitle','off');        
        plot( Lbow_sens(:,1),Lbow_sens(:,3),'color',[.05 .5 .06])
        axis([.5 1.50 .6 1.8 ])
        title('Bow section length L _b_o_w')
        annotation(e,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: L_b_o_w = ',num2str(Lbow),' [m]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter L_b_o_w change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'Red');        grid on
        legend('Riska','KV Svalbard')
        saveas(e,['Sensitivity\Lbow_h',num2str(H*10),'v',num2str(v),'.emf'])
        
        %% Lpar
        f=figure('Name','Sensitivity of Parallell hull section length',...
            'OuterPosition',pos{1},'NumberTitle','off');        
        plot( Lpar_sens(:,1),Lpar_sens(:,3),'color',[.05 .5 .06])
        axis([.5 1.50 .95 1.08 ])
        title('Parallell hull section length L _p_a_r')
        annotation(f,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: L_p_a_r = ',num2str(Lpar),' [m]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter L_p_a_r change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'r');
        grid on
        legend('Riska','KV Svalbard')
        saveas(f,['Sensitivity\Lpar_h',num2str(H*10),'v',num2str(v),'.emf'])

        %% Temperature
        f=figure('Name','Sensitivity of temperature',...
            'OuterPosition',pos{1},'NumberTitle','off');        
        plot( t_sens(:,1),t_sens(:,4),'color',[.05 .5 .06])
        axis([.2 1.8 .9 1.15 ])
        title('Temperature')
        annotation(f,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: t = ',num2str(t),' [deg celcius]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter temperature change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'r');
        grid on
        legend('Keinonen','KV Svalbard')
        saveas(f,['Sensitivity\temp',num2str(H*10),'v',num2str(v),'.emf'])
        %% Buttock angle
        f=figure('Name','Sensitivity of buttock angle',...
            'OuterPosition',pos{1},'NumberTitle','off');        
        plot( phi_b_sens(:,1),phi_b_sens(:,4),'color',[.05 .5 .06])
        axis([.5 1.50 .6 1.8 ])
        title('Buttock angle')
        annotation(f,'textbox',[0.2 0.8 .2 .1],...
            'String',{['Ice thickness = ',num2str(H),' [m]'], ['Vessel speed = ',num2str(v),' [m/s]'],['Origial value: phi_b = ',num2str(phi_b),' [deg]']},...
            'BackgroundColor',[1 1 1],'FitBoxToText','on');
        xlabel('Parameter buttock angle change coefficient')
        ylabel('Resistance change coefficient')
        hold on; scatter(1,1,'r');
        grid on
        legend('Keinonen','KV Svalbard')
        saveas(f,['Sensitivity\buttock',num2str(H*10),'v',num2str(v),'.emf'])
        %% Write file
        
        fprintf(fid,'h = %3.1f [m] v = %3.1f [m/s]\n',H,v);
        fprintf(fid,'\tParameter\t change factor\t Lindqvist\t Riska et al\n');
        fprintf(fid,'Phi:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[phi_sens(1,:);phi_sens(11,:)]');
        fprintf(fid,'Sigma:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[sigma_sens(1,:);sigma_sens(11,:)]');
        fprintf(fid,'Alpha:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[alpha_sens(1,:);alpha_sens(11,:)]');
        fprintf(fid,'My:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[my_sens(1,:);my_sens(11,:)]');
        fprintf(fid,'Lbow:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[Lbow_sens(1,:);Lbow_sens(11,:)]');
        fprintf(fid,'Lpar:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[Lpar_sens(1,:);Lpar_sens(11,:)]');
        fprintf(fid,'t:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[t_sens(1,:);t_sens(11,:)]');
        fprintf(fid,'phi_b:\t %4.2f\t %5.2f\t %5.2f\n \t%4.2f\t %5.2f\t %5.2f\n',[phi_b_sens(1,:);phi_b_sens(11,:)]');
        
                                
    end
end
fclose(fid);