% Creates statistical values for selected parameters in raw files
% Pseudocode in bottom of file
function [data dataLabel filename] = stat(ICEdata, NAVdata, HMADBdata,time)

%% input variables

dt=time/(24*3600);% [d] find statistical data for period of this length
di=round(dt/(ICEdata(2,1)-ICEdata(1,1)));%number of elements per period (!!Assuming constant sampling frequency)
% N=ceil((ICEdata(length(ICEdata),1)-ICEdata(1,1))/dt);%number of periods
N_ice=length(ICEdata);
N_nav=length(NAVdata);
N_eng=length(HMADBdata);

data=zeros(ceil(N_ice/di),17);
%Initiate variables
k_ice=1; k_nav=1; k_eng=1;
n=1;% period no
cont=true;
%% 
while cont==true 
    start=ICEdata(k_ice,1);%period start
    stop=start+dt;%period stop
    
    if stop>ICEdata(length(ICEdata),1)%if at end of file, stop (prevents error)
        break
    end
    
    %% ice file
    clear tmp_ice %resets saving variable
    j=1;% measurement no in period
    for i=k_ice:N_ice
        if ICEdata(i,1)>stop
            k_ice=i;
            break
        end
        tmp_ice(j,:)=ICEdata(i,:);
        j=j+1;
    end

    %% nav file
    j=1;% measurement no in period
    clear tmp_nav%resets saving variable

    for i=k_nav:N_nav
        if NAVdata(i,1)>stop
            k_nav=i;
            break
        end
        tmp_nav(j,:)=NAVdata(i,:);
        j=j+1;
    end

    %% engine data file
    j=1;% measurement no in period
    clear tmp_eng%resets saving variable

    for i=k_eng:N_eng
        if HMADBdata(i,1)>stop
            k_eng=i;
            break
        end
        tmp_eng(j,:)=HMADBdata(i,:);
        j=j+1;
    end   
    %% store data
    data(n,:)=[mean(tmp_ice(:,1)) (tmp_ice(size(tmp_ice,1),1)-tmp_ice(1,1)) mean(tmp_ice(:,2)) std(tmp_ice(:,2))...
        mean(tmp_nav(:,4)) std(tmp_nav(:,4)) mean(tmp_nav(:,5)) std(tmp_nav(:,5)) mean(tmp_eng(:,6)) std(tmp_eng(:,6)) ...
        mean(tmp_eng(:,11)) std(tmp_eng(:,11)) ...
        trapz(tmp_eng(:,1)*24*3600,tmp_eng(:,6)) trapz(tmp_eng(:,1)*24*3600,tmp_eng(:,11))...
        trapz(tmp_nav(:,1)*24*3600,tmp_nav(:,4)) tmp_nav(1,4) tmp_nav(length(tmp_nav),4)];  
    n=n+1;   
end

%% Save result file
dataLabel={'Mean Matlab Time','Time duration','Mean IceTh' 'std IceTh','mean Speed Over Ground', 'std SOG'...
    'mean Course over Ground', 'std COG','mean Pwr1','std Pwr1','mean Pwr2', 'std Pwr2', ...
    'int pwr1','int pwr2', 'int SOG', 'SOG start','SOG stop' }; %#ok<NASGU>

filename=['stat',num2str(time),'sek.mat'];
save(filename, 'data','time','dataLabel');

%% Pseudocode for statistical data creation
% 
% - Find size of all data files
% 
% - initiate storage matrix and counting variables
% 
% while (will be aborted by break)
%     chose start and stop time for current period
%     check for break (end of file)
%     for all data files
%         emty save files
%         collect all data within period
%     end
%     calculate statistical values for selected parameters for one period
%     perform time integration for selected variables
% end
% 
% - save result file to avoid doing it again    
